﻿using System;
using System.Collections.ObjectModel;
using System.Drawing;
using System.IO;
using System.Web;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WmsServerEdition;

namespace ThinkGeo.MapSuite.NearMapPlugins
{
    public class NauticalChartsPlugin : WmsLayerPlugin
    {
        private const string SrsDecimalDegree = "EPSG:4326";

        public NauticalChartsPlugin()
        {
            BrowerCacheExpiration = TimeSpan.FromSeconds(0);
            WmsQueryMode = WmsQueryMode.Queryable;
        }

        protected override RectangleShape GetBoundingBoxCore(string crs)
        {
            return new RectangleShape(-87.7672924, 42.0932118, -87.2534475, 41.565133);
        }

        protected override MapConfiguration GetMapConfigurationCore(string style, string crs)
        {
            MapConfiguration mapConfiguration = new MapConfiguration();

            mapConfiguration.Layers.Add("NearMap", new WorldMapKitLayer());

            FileBitmapTileCache tileCache = new FileBitmapTileCache();
            tileCache.CacheDirectory = @"D:\Temp\WmsTileCacheTest";
            tileCache.CacheId = "MyLayerName";
            tileCache.ExpirationTime = new TimeSpan(0, 5, 0);
            tileCache.TileAccessMode = TileAccessMode.ReadAddDelete;
            mapConfiguration.TileCache = tileCache;

            return mapConfiguration;
        }

        protected override Bitmap GetMapCore(GetMapRequest getMapRequest, MapConfiguration cachedMapConfiguration, HttpContext context)
        {
            return base.GetMapCore(getMapRequest, cachedMapConfiguration, context);
        }

        protected override string GetNameCore()
        {
            return "WorldMap";
        }

        protected override Collection<string> GetProjectionsCore()
        {
            return new Collection<string> { SrsDecimalDegree };
        }

        protected override GeographyUnit GetGeographyUnitCore(string crs)
        {
            return GeographyUnit.DecimalDegree;
        }
    }
}
